MappableArea

Trait MappableArea 

pub trait MappableArea: Clone + Debug {
    // Required method
    fn can_map(&self, addr: Addr) -> bool;
}
The memory addresses that can be mapped by an oracle.

Required Methods

fn can_map(&self, addr: Addr) -> bool

Returns true if the address addr can be mapped.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors